from django.apps import AppConfig
from django.core.checks import register

from . import __version__


class AlumniConfig(AppConfig):
    default_auto_field = 'django.db.models.BigAutoField'
    name = "alumni"
    label = "alumni"
    verbose_name = f"alumni v{__version__}"

    def ready(self):
        from alumni.checks import esi_endpoint_offline
        register()(esi_endpoint_offline)



from django.core.checks import Info


def esi_endpoint_offline(*args, **kwargs):
    errors = []
    errors.append(Info(
        'Corp History Endpoint Offline',
        hint='Alumni will be unable to update Character Corporation Histories until CCP restore this endpoint https://github.com/esi/esi-issues/blob/master/changelog.md#2023-01-09'))
    return errors
